def valid(number):
    """
    Returns true if the number string is luhn valid, and false otherwise.  The
    number string passed to the function must contain only numeric characters
    otherwise behavior is undefined.
    """
    checksum = 0

    number_len = len(number)
    offset = ord('0')

    i = number_len - 1
    while i >= 0:
      n = ord(number[i]) - offset
      checksum += n
      i -= 2

    i = number_len - 2
    while i >= 0:
      n = ord(number[i]) - offset
      n *= 2
      if n > 9:
          n -= 9
      checksum += n
      i -= 2

    return checksum%10 == 0



from setuptools import setup

def readme():
    return open('./README.rst').read()

setup(name='luhnmod10',
      version='1.0.2',
      description='A fast and simple in-place implementation of the luhn check algorithm.',
      long_description=readme(),
      url='https://github.com/luhnmod10/python',
      author='Leigh McCulloch',
      license='MIT',
      packages=['luhnmod10'],
      zip_safe=True,
      )
